#ifndef __CONFIG_H__
#define __CONFIG_H__


#define CONFIG_ERROR_FILE_OPEN 1
#define CONFIG_ERROR_PARSE 2

class CConfig{
protected:
	std::map<std::string,std::string> m_Data;
public:
	CConfig(){}
	virtual ~CConfig(){}

	//---Reads config file
	int Load(const char *pFile){
		FILE *fp=fopen(pFile,"r");
		if(!fp)return CONFIG_ERROR_FILE_OPEN;

		//clear old data
		m_Data.clear();

		//read each line
		char buf[256];
		std::string linebuf;
		for(;;){
			char *pRes=fgets(buf,sizeof(buf)/sizeof(buf[0])-1,fp);
			//trim CR & LF
			bool bEOL=false;	//true if buffer reaches end of line
			for(;;){
				size_t len=strlen(buf);
				if( buf[len-1]=='\n' || buf[len-1]=='\r'){
					buf[len-1]='\0';
					bEOL=true;
				}else break;
			}
			linebuf+=buf;
			if(!pRes)bEOL=true;

			if(bEOL && !linebuf.empty()){
				//split line by '='

				if(linebuf[0]!=';'){	//line begins with ';' is a comment line
					std::string strKey;
					size_t len=linebuf.length();

					size_t idx=0;
					for(;idx<len;idx++){
						if(linebuf[idx]=='='){
							idx++;
							break;
						}else{
							strKey+=linebuf[idx];
						}
					}
					if(idx>=len){
						fclose(fp);
						return CONFIG_ERROR_PARSE;
					}

					//make strKey lower
					std::transform(strKey.begin(), strKey.end(), strKey.begin(), tolower);

					//store data
					m_Data[strKey]=linebuf.c_str()+idx;
				}

				linebuf.clear();
			}
			if(!pRes)break;
		}

		fclose(fp);
		return 0;
	}

	//---Accessors
	int getInt(const char* pKey,int def=0){
		if(m_Data[pKey].empty())return def;
		return atoi(m_Data[pKey].c_str());
	}

	float getFloat(const char* pKey,float def=0.0f){
		if(m_Data[pKey].empty())return def;
		return (float)atof(m_Data[pKey].c_str());
	}

	const char* operator[](const char* pKey){
		return m_Data[pKey].c_str();
	}
	const char* getStr(const char* pKey){
		return m_Data[pKey].c_str();
	}
};

#endif//__CONFIG_H__

